@@ -248,7 +248,7 @@ class Client(AccountsEndpointsMixin, DiscoverEndpointsMixin, FeedEndpointsMixin,
         """Override the useragent string with your own"""
         mobj = re.search(Constants.USER_AGENT_EXPRESSION, value)
         if not mobj:
-            raise Value'User-agent specified does not fit format required: {0!s}'.format(
+            raise ValueError("Insta_cs : "+'User-agent specified does not fit format required: {0!s}'.format(
                 Constants.USER_AGENT_EXPRESSION))
         self.app_version = mobj.group('app_version')
         self.android_release = mobj.group('android_release')
